==> appwatch_0.56-1.tar.gz: appwatch-0.56/src/repostat.cpp <==
#include "repostat.h"
#include "fremantlerepochooser.h"
#include "rangepicker.h"
#include <QDate>
#include <QFile>
#include <QFileInfo>
#include <QTextStream>
#include <QDebug>
#include <QNetworkAccessManager>
#include <QNetworkDiskCache>

RepoStat::RepoStat(QWidget* parent): QMainWindow(parent), settings("AppWatch", "RepoStat")
{
    ui.setupUi(this);
//    m_fullscreen = new QAction(QIcon::fromTheme("general_fullsize"), QString(), this);
/*    m_fullscreen = new QAction(QIcon(), QString(), this);
    m_fullscreen->setCheckable(true);
    connect(m_fullscreen, SIGNAL(toggled(bool)), this, SLOT(toggleFullScreen(bool)));
    QToolBar *tb = new QToolBar(this);
    tb->addAction(m_fullscreen);
    addToolBar(tb);
*/
    connect(ui.action_Settings, SIGNAL(triggered()), this, SLOT(showRepoChooser()));
    connect(ui.action_Date_range, SIGNAL(triggered()), this, SLOT(showRangeChooser()));

    manager = new QNetworkAccessManager(this);
    qDebug() << settings.fileName();
    QNetworkDiskCache *diskCache = new QNetworkDiskCache(this);
    diskCache->setCacheDirectory(QFileInfo(settings.fileName()).absolutePath() + "/cacheDir");
    manager->setCache(diskCache);

    getData();

    connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(loadStat(QNetworkReply*)));

    ////
    ////  Setup view & scene
    ////

    ui.graphicsView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    ui.graphicsView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    ui.graphicsView->setAlignment(Qt::AlignLeft | Qt::AlignTop);
    ui.graphicsView->setRenderHint(QPainter::Antialiasing);

}

void RepoStat::getData()
{
    QString interval = settings.value("interval", QVariant("m")).toString();

    // do a request preferred from cache
    QNetworkRequest request(QUrl(QString("http://app.cache.rs/repostat/line?scale=%1&fmt=z").arg(interval)));
//    request.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::AlwaysCache);
    request.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::PreferCache);
    manager->get(request);
}

void RepoStat::showRangeChooser()
{
    RangePicker rp(settings.value("interval", QVariant("m")).toString());
    if (rp.exec() > 0)
        settings.setValue("interval", rp.range());
        getData();
}

void RepoStat::showRepoChooser()
{
    FremantleRepoChooser rc("RepoStat");
    if (rc.exec() > 0)
        getData();
}

void RepoStat::loadStat(QNetworkReply* reply)
{

    QVariant fromCache = reply->attribute(QNetworkRequest::SourceIsFromCacheAttribute);
    qDebug() << "stat page from cache?" << fromCache.toBool();

    QGraphicsScene* scene = ui.graphicsView->scene();
    if (scene)
        delete scene;
    scene = new QGraphicsScene();
    ui.graphicsView->setScene(scene);

    ////
    ////  Load graph data
    ////

    if (settings.allKeys().length() == 0) { // none selected, cludgy way to get defaults
        FremantleRepoChooser* rc = new FremantleRepoChooser("RepoStat");
        rc->saveChoice();
        delete rc;
    }

    ////
    ////  Load graph data
    ////
    if (!reply->open(QIODevice::ReadOnly | QIODevice::Text)){
       return;
    }
    QTextStream in(reply);
    QString lastline = "";
    bool skipds = true; // set this to true to avoid referencing a datasourec before the first one
    int elemcount = 0;
    int prevx, prevy = 0;
    QPen pen;
    pen.setWidth(2);
    pen.setCosmetic(true);
    while (!in.atEnd()) {
       QString line = in.readLine();
       QStringList list = line.split(",");
       if (list.length() < 1 || line.isEmpty()) {
           lastline = line;
           continue;
       }
       if (lastline.isEmpty()) { // header line
           skipds = false;
           if (settings.value(list[0], QVariant(0)).toInt() == 0){
               skipds = true;
           }
           pen.setColor(QColor::fromRgb(QRgb(list[1].toInt(NULL, 16))));
           elemcount = 0;
       } else if (!skipds) {
           if (elemcount > 0) {
               scene->addLine(prevx, -prevy, list[0].toInt(), -list[1].toInt(), pen);
           }
           prevx = list[0].toInt();
           prevy = list[1].toInt();
           elemcount++;
       }
       lastline = line;
    }

    reply->deleteLater();
    this->show();
    ui.graphicsView->fitInView(scene->sceneRect(), Qt::IgnoreAspectRatio);
}

void RepoStat::resizeEvent(QResizeEvent* event)
{
    ui.graphicsView->fitInView(ui.graphicsView->sceneRect(), Qt::IgnoreAspectRatio);
}

void RepoStat::toggleFullScreen(bool b)
{
    setWindowState(b ? windowState() | Qt::WindowFullScreen
                     : windowState() & ~Qt::WindowFullScreen);
}

RepoStat::~RepoStat()
{
    delete manager;

}

==> appwatch_0.70-1.tar.gz: appwatch-0.70/src/repostat.cpp <==
#include "repostat.h"
#include "fremantlerepochooser.h"
#include "rangepicker.h"
#include <QDate>
#include <QFile>
#include <QFileInfo>
#include <QTextStream>
#include <QDebug>
#include <QNetworkAccessManager>
#include <QNetworkDiskCache>
#include <QProgressBar>
#include <QGraphicsSimpleTextItem>

RepoStat::RepoStat(QWidget* parent): QMainWindow(parent), settings("AppWatch", "RepoStat")
{
    ui.setupUi(this);
//    m_fullscreen = new QAction(QIcon::fromTheme("general_fullsize"), QString(), this);
/*    m_fullscreen = new QAction(QIcon(), QString(), this);
    m_fullscreen->setCheckable(true);
    connect(m_fullscreen, SIGNAL(toggled(bool)), this, SLOT(toggleFullScreen(bool)));
    QToolBar *tb = new QToolBar(this);
    tb->addAction(m_fullscreen);
    addToolBar(tb);
*/
    connect(ui.action_Settings, SIGNAL(triggered()), this, SLOT(showRepoChooser()));
    connect(ui.action_Date_range, SIGNAL(triggered()), this, SLOT(showRangeChooser()));

    progress.setRange(0,0);

    manager = new QNetworkAccessManager(this);
    qDebug() << settings.fileName();
    QNetworkDiskCache *diskCache = new QNetworkDiskCache(this);
    diskCache->setCacheDirectory(QFileInfo(settings.fileName()).absolutePath() + "/cacheDir");
    manager->setCache(diskCache);

    getData();

    connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(loadStat(QNetworkReply*)));

    ////
    ////  Setup view & scene
    ////

    ui.graphicsView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    ui.graphicsView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    ui.graphicsView->setAlignment(Qt::AlignLeft | Qt::AlignTop);
    ui.graphicsView->setRenderHint(QPainter::Antialiasing);

}

void RepoStat::getData()
{
    QString interval = settings.value("interval", QVariant("m")).toString();

    // do a request preferred from cache
    QNetworkRequest request(QUrl(QString("http://app.cache.rs/repostat/line?scale=%1&fmt=z").arg(interval)));
//    request.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::AlwaysCache);
    request.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::PreferCache);
    QNetworkReply* reply = manager->get(request);
//    connect(reply, SIGNAL(downloadProgress(qint64,qint64)), &progressdialog, SLOT(setRange(qint, qint)));
//    QProgressBar * qpb = new QProgressBar;
//    progressdialog.setBar(qpb);
//    connect(reply, SIGNAL(downloadProgress(int,int)), qpb, SLOT(setValue(int)));
    //connect(reply, SIGNAL(downloadProgress(qint64,qint64)), &progressdialog, SLOT(setValue(int)));
//    progressdialog.exec();
    progress.show();

}

void RepoStat::showRangeChooser()
{
    RangePicker rp(settings.value("interval", QVariant("m")).toString());
    if (rp.exec() > 0)
        settings.setValue("interval", rp.range());
        getData();
}

void RepoStat::showRepoChooser()
{
    FremantleRepoChooser rc("RepoStat");
    if (rc.exec() > 0)
        getData();
}

void RepoStat::loadStat(QNetworkReply* reply)
{

    QVariant fromCache = reply->attribute(QNetworkRequest::SourceIsFromCacheAttribute);
    qDebug() << "stat page from cache?" << fromCache.toBool();

    progress.hide();

    QGraphicsScene* scene = ui.graphicsView->scene();
    if (scene)
        delete scene;
    scene = new QGraphicsScene();
    ui.graphicsView->setScene(scene);

    ////
    ////  Load graph data
    ////

    if (settings.allKeys().length() == 0) { // none selected, cludgy way to get defaults
        FremantleRepoChooser* rc = new FremantleRepoChooser("RepoStat");
        rc->saveChoice();
        delete rc;
    }

    ////
    ////  Load graph data
    ////
    if (!reply->open(QIODevice::ReadOnly | QIODevice::Text)){
       return;
    }
    QTextStream in(reply);
    QString lastline = "";
    bool skipds = true; // set this to true to avoid referencing a datasourec before the first one
    int elemcount = 0;
    int prevx, prevy = 0;
    QPen pen;
    pen.setWidth(2);
    pen.setCosmetic(true);
    while (!in.atEnd()) {
       QString line = in.readLine();
       QStringList list = line.split(",");
       if (list.length() < 1 || line.isEmpty()) {
           lastline = line;
           continue;
       }
       if (lastline.isEmpty()) { // header line
           skipds = false;
           if (settings.value(list[0], QVariant(0)).toInt() == 0){
               skipds = true;
           }
           pen.setColor(QColor::fromRgb(QRgb(list[1].toInt(NULL, 16))));
           pen.setWidth(1);
           elemcount = 0;
       } else if (!skipds) {
           if (elemcount > 0) {
               scene->addLine(prevx, -prevy, list[0].toInt(), -list[1].toInt(), pen);
               pen.setColor(pen.color().lighter(103));
               pen.setWidthF(pen.widthF()+0.2);
           } else { // first entry
                scene->addLine(0, -list[1].toInt(), -5, -list[1].toInt(),QPen(QColor("black")));
                QGraphicsSimpleTextItem* valtext = scene->addSimpleText(list[1]);
                valtext->setFlag(QGraphicsItem::ItemIgnoresTransformations, true);
                valtext->moveBy(-25, -8-list[1].toInt());

           }
           prevx = list[0].toInt();
           prevy = list[1].toInt();
           elemcount++;
       }
       lastline = line;
    }

    QRectF srect = scene->sceneRect();
    scene->addLine(-10, 0, srect.width(),0,QPen(QColor("grey")));
    scene->addLine(srect.width()-10, 3, srect.width(),0,QPen(QColor("grey")));
    scene->addLine(srect.width()-10, -3, srect.width(),0,QPen(QColor("grey")));

    scene->addLine(0, 10, 0, -srect.height(),QPen(QColor("grey")));
    scene->addLine(3, -srect.height()+10, 0, -srect.height(),QPen(QColor("grey")));
    scene->addLine(-3, -srect.height()+10, 0, -srect.height(),QPen(QColor("grey")));

    reply->deleteLater();
    this->show();
    QTransform transform;
    transform.scale(12,8);
    transform.rotate(71.5, Qt::YAxis);
    transform.translate(0, 50);
//    transform.rotate(-21.5, Qt::XAxis);
//    transform.scale(1.0, 21.5);
    ui.graphicsView->setTransform(transform);
    ui.graphicsView->fitInView(scene->itemsBoundingRect(), Qt::IgnoreAspectRatio);
//    ui.graphicsView->fitInView(scene->sceneRect());
}

void RepoStat::resizeEvent(QResizeEvent* event)
{
    ui.graphicsView->fitInView(ui.graphicsView->sceneRect(), Qt::IgnoreAspectRatio);
}

void RepoStat::toggleFullScreen(bool b)
{
    setWindowState(b ? windowState() | Qt::WindowFullScreen
                     : windowState() & ~Qt::WindowFullScreen);
}

RepoStat::~RepoStat()
{
    delete manager;

}
